==> easeftp-2.0.32.tgz: package/index.js <==
/*
var easeftp = require('easeftp');
easeftp.verify({
	"username": "...",
	"password": "..."
}).then(function() {
	return easeftp.upload({
		online: "test/test1/......",
		file: "绝对路径", 	// 需要上传的文件路径
		files: "绝对路径", 	// 需要上传的文件夹路径
						  	// 文件和文件夹只能选择其一，否则按照文件上传处理
		exclude:["*.js","**.js","..."]   // 排除其中不上传的文件
	})
}).then(([successArr,failArr]) => {
	// successArr 	上传成功
	// failArr 		上传失败
	// complete
})
* */

const {add, auth} = require('./upload');
const path = require('path');
const fs = require('fs');

const _glob = require('glob');
const {promisify} = require('util');
const glob = promisify(_glob);

var Minimatch = require("minimatch").Minimatch;


const log = {
    alert: function (text) {
        console.log(text.yellow);
    },
    err: function (text) {
        console.log(text.red);
    },
    success: function (text) {
        console.log(text.green);
    }
}

var sessionId;
const verify = function ({username, password}) {

    var errTxt;
    if (!(username && password)) {
        errTxt = 'username 和 password 不允许为空';
    }

    if (!(typeof username === 'string' && typeof password === 'string')) {
        errTxt = 'username和password必须为字符串类型'
    }

    if (errTxt) {
        log.err(errTxt);
        throw new Error(errTxt);
    }

    return auth(username, password).then((id) => sessionId = id)
}

const upload = async function ({online, file, files, exclude}) {

    var errTxt;
    if (!online) {
        errTxt = 'online不允许为空';
    }

    if (!file && !files) {
        errTxt = 'file 和 files 必须指定其中一个参数 '
    }

    var pattern = ((file || files) + '').trim();

    if (!pattern) {
        errTxt = 'file和files不允许传入空字符串';
    }

    if (errTxt) {
        log.err(errTxt);
        throw new Error(errTxt);
    }

    if (file) {
        var stat = fs.statSync(pattern);
        if (!stat.isFile()) {
            errTxt = `未找到file参数指定的文件: ${pattern}`;
            log.err(errTxt);
            throw new Error(errTxt);
        }
    }
    else { //说明pattern为files
        pattern = path.join(pattern, '/**/*.*');
    }


    /**
     * @type {Array}
     */
    var fileList = await glob(pattern, {absolute: true});


    if (Array.isArray(exclude) && exclude.length > 0) {
        //exclude的逻辑，保持和原代码逻辑一致

        exclude = exclude.map(item => path.join('**/', path.sep, item));

        fileList = fileList.filter((file) => {
            return !exclude.some(p => {
                return minimatch(file, p);
            })
        })
    }


    var {urls, details} = await add(fileList, {
        session: sessionId,
        path: online,
        debug: true
    });


    var toV1Url = function (url) {
        return url.replace(`https://static.ws.126.net/163/${online}/`, '');
    }

    var successArr = urls.map(url => {
        return {
            error: null,
            cdnUrl: url,
            url: toV1Url(url)
        };
    });

    var failArr = details.filter((item) => item.error).map((item) => {
        item.cdnUrl = item.url;
        item.url = toV1Url(item.url);
        return item;
    })

    return [successArr, failArr];

}

module.exports = {
    verify,
    upload
};

// upload({
//     online: "test/test1/......",
//     // file: "./dist/app.js", 	// 需要上传的文件路径
//     files: "./dist/", 	// 需要上传的文件夹路径
//     // 文件和文件夹只能选择其一，否则按照文件上传处理
//     exclude: ["*.js", "**.js", "..."]   // 排除其中不上传的文件
// })

// console.log(minimatch('/adf/adsf/abc.js','/*.js'))

==> easeftp-2.0.39.tgz: package/index.js <==
/*
var easeftp = require('easeftp');
easeftp.verify({
	"username": "...",
	"password": "..."
}).then(function() {
	return easeftp.upload({
		online: "test/test1/......",
		file: "绝对路径", 	// 需要上传的文件路径
		files: "绝对路径", 	// 需要上传的文件夹路径
						  	// 文件和文件夹只能选择其一，否则按照文件上传处理
		exclude:["*.js","**.js","..."]   // 排除其中不上传的文件
	})
}).then(([successArr,failArr]) => {
	// successArr 	上传成功
	// failArr 		上传失败
	// complete
})
* */

const {add, auth} = require('./upload');
const path = require('path');
const fs = require('fs');

const _glob = require('glob');
const {promisify} = require('util');
const glob = promisify(_glob);

var Minimatch = require("minimatch").Minimatch;


const log = {
    alert: function (text) {
        console.log(text.yellow);
    },
    err: function (text) {
        console.log(text.red);
    },
    success: function (text) {
        console.log(text.green);
    }
}

var sessionId;
const verify = function ({username, password}) {

    var errTxt;
    if (!(username && password)) {
        errTxt = 'username 和 password 不允许为空';
    }

    if (!(typeof username === 'string' && typeof password === 'string')) {
        errTxt = 'username和password必须为字符串类型'
    }

    if (errTxt) {
        log.err(errTxt);
        throw new Error(errTxt);
    }

    return auth(username, password, true).then((id) => sessionId = id)
}

const upload = async function ({online, file, files, exclude}) {

    var errTxt;
    if (!online) {
        errTxt = 'online不允许为空';
    }

    if (!file && !files) {
        errTxt = 'file 和 files 必须指定其中一个参数 '
    }

    var pattern = ((file || files) + '').trim();

    if (!pattern) {
        errTxt = 'file和files不允许传入空字符串';
    }

    if (errTxt) {
        log.err(errTxt);
        throw new Error(errTxt);
    }

    if (file) {
        var stat = fs.statSync(pattern);
        if (!stat.isFile()) {
            errTxt = `未找到file参数指定的文件: ${pattern}`;
            log.err(errTxt);
            throw new Error(errTxt);
        }
    }
    else { //说明pattern为files
        pattern = path.join(pattern, '/**/*.*');
    }


    /**
     * @type {Array}
     */
        // var fileList = await glob(pattern, {absolute: true});
        //
        //
        // if (Array.isArray(exclude) && exclude.length > 0) {
        //     //exclude的逻辑，保持和原代码逻辑一致
        //
        //     exclude = exclude.map(item => path.join('**/', path.sep, item)).map(p => Minimatch(p));
        //
        //     fileList = fileList.filter((file) => {
        //         return !exclude.some(mm => mm.match(file))
        //     })
        // }


        // var {urls, details} = await add(fileList, {
        //     session: sessionId,
        //     path: online,
        //     debug: true
        // });

    var {urls, details} = await add(pattern, {
            session: sessionId,
            path: online,
            debug: true,
            exclude
        }).then((data) => data, (data) => data);


    var toV1Url = function (url) {
        return url.replace(`https://static.ws.126.net/163/${online}/`, '');
    }

    var successArr = urls.map(url => {
        return {
            error: null,
            cdnUrl: url,
            url: toV1Url(url)
        };
    });

    var failArr = details.filter((item) => item.error).map((item) => {
        item.cdnUrl = item.url;
        item.url = toV1Url(item.url);
        return item;
    })

    return [successArr, failArr];

}

module.exports = {
    verify,
    upload
};

// upload({
//     online: "test/test1/......",
//     // file: "./dist/app.js", 	// 需要上传的文件路径
//     files: "./dist/", 	// 需要上传的文件夹路径
//     // 文件和文件夹只能选择其一，否则按照文件上传处理
//     exclude: ["*.js", "**.js", "..."]   // 排除其中不上传的文件
// })

// console.log(minimatch('/adf/adsf/abc.js','/*.js'))
